# Mini_GUI_Games
### small funny games

## Installation

## Usage

## Screenshots

### HannoiTower
![](screenshots/hanoitower1.png) | ![](screenshots/hanoitower2.png)
:--- | :---

### TicTacToe
![](screenshots/tictactoe1.png) | ![](screenshots/tictactoe2.png) | ![](screenshots/tictactoe3.png) | ![](screenshots/tictactoe4.png)
:--- | :--- | :--- | :--- 

### Snake
![](screenshots/snake1.png) | ![](screenshots/snake2.png) | ![](screenshots/snake3.png)
:--- | :--- | :--- 

### BanderGoose
![](screenshots/bandergoose1.png) | ![](screenshots/bandergoose2.png)
:--- | :--- 
